@@ -1,7 +1,8 @@
-from SparkleLogging.utils.getLog import LogManager ,FOMATTER
-from logging import DEBUG, INFO, WARNING, ERROR, CRITICAL,FATAL
+from SparkleLogging.utils.getLog import LogManager ,DEFAUIT_FOMATTER
+from logging import DEBUG, INFO, WARNING, ERROR, CRITICAL,FATAL ,Formatter
 
-DEFAULT_LOGGER = LogManager().GetLogger(
+# 默认的日志记录器
+DEFAULT_LOGGER = LogManager.GetLogger(
     log_name='main',
     setConsoleLevel=DEBUG,
     setFileLevel=INFO,
@@ -12,5 +13,5 @@ DEFAULT_LOGGER = LogManager().GetLogger(
     WSpost_url="",
     HTTPpost_url="",
     http_mode=False,
-    custom_formatter=FOMATTER
+    custom_formatter=DEFAUIT_FOMATTER
 )
\ No newline at end of file
